sailthru-python-client
====================


For installation instructions, documentation, and examples please visit:
[http://getstarted.sailthru.com/developers/api-libraries/python](http://getstarted.sailthru.com/developers/api-libraries/python)

A simple client library to remotely access the `Sailthru REST API` as per [http://getstarted.sailthru.com/api](http://getstarted.sailthru.com/developers/api)

Python binding for [Sailthru API](http://getstarted.sailthru.com/api) based on [Requests](https://github.com/kennethreitz/requests)

It will make request in `JSON` format.

Tested with `Python 2.7.x` but it should work with 2.6.x also.

### Installation (Tested with Python 2.7.x)

Installing with [pip](http://www.pip-installer.org/):

    pip install sailthru-client
    
### Running tests
    nosetests -v
